@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gog-label.h : 
+ * gog-label.h :
  *
  * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  * Copyright (C) 2005      Jean Brefort (jean.brefort@normalesup.org)
@@ -22,20 +22,19 @@
 #ifndef GOG_LABEL_H
 #define GOG_LABEL_H
 
-#include <goffice/graph/goffice-graph.h>
-#include <glib-object.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
-#define GOG_LABEL_TYPE	(gog_label_get_type ())
-#define GOG_LABEL(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_LABEL_TYPE, GogLabel))
-#define IS_GOG_LABEL(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_LABEL_TYPE))
+#define GOG_TYPE_LABEL	(gog_label_get_type ())
+#define GOG_LABEL(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_LABEL, GogLabel))
+#define GOG_IS_LABEL(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_LABEL))
 
 GType gog_label_get_type (void);
 
-#define GOG_REG_EQN_TYPE	(gog_reg_eqn_get_type ())
-#define GOG_REG_EQN(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_REG_EQN_TYPE, GogRegEqn))
-#define IS_GOG_REG_EQN(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_REG_EQN_TYPE))
+#define GOG_TYPE_REG_EQN	(gog_reg_eqn_get_type ())
+#define GOG_REG_EQN(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_REG_EQN, GogRegEqn))
+#define GOG_IS_REG_EQN(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_REG_EQN))
 
 GType gog_reg_eqn_get_type (void);
 
